<?php
/**
 * The general interface for all other database interfaces
 *
 * @author	Roland Haeder <roland __NOSPAM__ [at] __REMOVE_ME__ mxchange [dot] org>
 * @version	0.1
 */
interface FrameworkDatabaseInterface extends FrameworkInterface {
	/**
	 * Saves a whole object by serializing it entirely or some specifyable
	 * parts. Specifying parts must be done before this method is called. If
	 * it is not done this method will serialize the whole object.
	 *
	 * @param		$object	An instance to the object we want to save
	 * @return	void
	 * @see		limitObject(ObjectLimits)	limitObject
	 */
	function saveObject ($object);

	/**
	 * Analyses if a unique ID has already been used or not. This method does
	 * only pass the given ID through to the "real" database layer.
	 *
	 * @param		$uniqueID		A unique ID number which shall be checked
	 *						before it will be used
	 * @param		$inConstructor	If called from a constructor or from
	 *						somewhere else
	 * @return	$isUnused		true	= The unique ID was not found in the database,
	 *						false = It is already in use by an other object
	 * @throws	NullPointerException	If $dbInstance is null
	 * @throws	NoObjectException		If $dbInstance is not an object
	 * @throws	MissingMethodException	If the required method
	 *								isUniqueIdUsed() was not found
	 */
	function isUniqueIdUsed ($uniqueID, $inConstructor = false);

	/**
	 * Gets cached data from the database layer and if not found fetch it from
	 * the database again. This method does not return the header stuff because
	 * The underlaying database class will return only the requested content.
	 *
	 * @param		$idNumber		The ID number which we need for looking up
	 *						the requested data
	 * @return	$cachedArray	The maybe cached data from the database
	 * @throws	NullPointerException	If $dbInstance is null
	 * @throws	NoObjectException		If $dbInstance is not an object
	 * @throws	MissingMethodException	If the required method
	 *								isUniqueIdUsed() was not found
	 */
	function getObjectFromCachedData ($idNumber);
}

// [EOF]
?>
