<?php
/**
 * Null compression and decompression class
 */
class NullCompressor extends BaseFrameworkSystem implements Compressor {
	/**
	 * Private constructor
	 *
	 * @return	void
	 */
	private function __construct () {
		// Call parent constructor!
		parent::constructor(__CLASS__);

		// Debug message
		if (((defined('DEBUG_COMPRESSOR')) || (defined('DEBUG_ALL'))) && (defined('DEBUG_CONSTRUCT'))) $this->getDebugInstance()->output(sprintf("[%s:] Konstruktor erreicht.<br />\n",
			$this->__toString()
		));

		// Set description
		$this->setPartDescr("Null-Kompressor");

		// Create an unique ID
		$this->createUniqueID();
	}

	/**
	 * Create a new compressor channel based a given compression handler
	 *
	 * @return	$cInstance	An instance of this class
	 */
	public final static function createNullCompressor () {
		// Get new instance
		$cInstance = new NullCompressor();

		// Return the compressor instance
		return $cInstance;
	}

	/**
	 * Null compression stream
	 *
	 * @param		$streamData			Mixed non-object stream data
	 * @return	$streamData			The compressed stream data	
	 * @throws	InvalidObjectException	If the stream is an object
	 */
	public function compressStream ($streamData) {
		if (is_object($streamData)) {
			// Throw an exception
			throw new InvalidObjectException($streamData, self::EXCEPTION_UNEXPECTED_OBJECT);
		}

		// Return the compressed stream
		return $streamData;
	}

	/**
	 * Null decompression stream
	 *
	 * @param		$streamData			Mixed non-object stream data
	 * @return	$streamData			The decompressed stream data	
	 * @throws	InvalidObjectException	If the stream is an object
	 */
	public function decompressStream ($streamData) {
		if (is_object($streamData)) {
			// Throw an exception
			throw new InvalidObjectException($streamData, self::EXCEPTION_UNEXPECTED_OBJECT);
		}

		// Return the decompressed stream
		return $streamData;
	}

	/**
	 * Getter for the file extension of this compressor
	 *
	 * @return	$string	Returns always "bz2"
	 */
	public final function getCompressorExtension () {
		if ((defined('DEBUG_COMPRESSOR')) || (defined('DEBUG_ALL'))) $this->getDebugInstance()->output(sprintf("[%s:] Dateierweiterung angefordert.<br />\n",
			$this->__toString()
		));
		return "null";
	}
}

// [EOF]
?>
