<?php
/**
 * This class simply puts HTML code / JavaScript code or CSS code out to the
 * browser
 */
class ConsoleOutput extends BaseFrameworkSystem implements OutputStreamer {
	/**
	 * The instance for the singleton design pattern
	 */
	private static $consoleInstance = null;

	/**
	 * Assigned variables
	 */
	private $vars = array();

	/**
	 * Private constructor
	 *
	 * @return	void
	 */
	private function __construct () {
		// Call parent constructor
		parent::constructor(__CLASS__);

		// Set description
		$this->setPartDescr("Console-Ausgabe-Handler");

		// Create an unique ID
		$this->createUniqueID();
	}

	/**
	 * Create a new web output system and set the content type
	 *
	 * @param		$contentType		A valid content-type
	 * @return	$debugInstance		An instance of this middleware class
	 */
	public final static function createConsoleOutput ($contentType) {
		// Cast the content-type to string
		$contentType = (string) $contentType;
		$contentType = trim($contentType);

		// Get instance
		self::$consoleInstance = new ConsoleOutput();

		// Set the content type
		if (!empty($contentType)) {
			@header(sprintf("Content-type: %s",
				$contentType
			));
		}

		// Return instance
		return self::$consoleInstance;
	}

	/**
	 * Getter for an instance of this class
	 *
	 * @return	$consoleInstance		An instance of this class
	 */
	public final static function getInstance() {
		if (is_null(self::$consoleInstance)) {
			$contentType = FrameworkConfiguration::getInstance()->readConfig("web_content_type");
			self::$consoleInstance = ConsoleOutput::createConsoleOutput($contentType);
		}
		return self::$consoleInstance;
	}

	/**
	 * Output the code
	 *
	 * @param		$outStream	Something we shall sent to the console
	 * @return	void
	 */
	public final function output ($outStream=false) {
		if ($outStream === false) {
			// Output something here...
			foreach ($this->vars as $var=>$value) {
				$this->output("var=".$var.", value=".$value."");
			}
		} else {
			// Output it to the console
			printf("%s\n", trim(html_entity_decode(strip_tags($outStream))));
		}
	}

	/**
	 * Assigns a variable for output
	 *
	 * @param		$var		The variable we shall assign
	 * @param		$value	The value to store in the variable
	 * @return	void
	 */
	public function assignVariable ($var, $value) {
		$this->vars[$var] = $value;
	}
}

// [EOF]
?>
