<?php
/**
 * This class simply puts HTML code / JavaScript code or CSS code out to the
 * browser
 */
class WebOutput extends BaseFrameworkSystem implements OutputStreamer {
	/**
	 * The instance for the singleton design pattern
	 */
	private static $webInstance = null;

	/**
	 * Private constructor
	 *
	 * @return	void
	 */
	private function __construct () {
		// Call parent constructor
		parent::constructor(__CLASS__);

		// Set description
		$this->setPartDescr("Web-Ausgabe-Handler");

		// Create an unique ID
		$this->createUniqueID();
	}

	/**
	 * Create a new web output system and set the content type
	 *
	 * @param		$contentType		A valid content-type
	 * @return	$debugInstance		An instance of this middleware class
	 */
	public final static function createWebOutput ($contentType) {
		// Is there no instance?
		if (is_null(self::$webInstance)) {
			// Cast the content-type to string and trim it
			$contentType = (string) $contentType;
			$contentType = trim($contentType);

			// Set the content type
			if (!empty($contentType)) {
				@header(sprintf("Content-type: %s",
					$contentType
				));
			}

			// Get a new instance and set it
			self::$webInstance = new WebOutput();
		}

		// Return instance
		return self::$webInstance;
	}

	/**
	 * Assigns a variable for output
	 *
	 * @param		$var		The variable we shall assign
	 * @param		$value	The value to store in the variable
	 * @return	void
	 */
	public function assignVariable($var, $value) {
		// Stub message because we don't have it here
		trigger_error(__METHOD__.": Stub!");
	}

	/**
	 * Output the code
	 *
	 * @return	void
	 */
	public final function output ($outStream=false) {
		print $outStream;
	}
}

// [EOF]
?>
